@@ -18,6 +18,21 @@
 #ifndef ANDROID_DEFAULT
 # define ANDROID_DEFAULT 0
 #endif
+#ifndef TARGET_DEFAULT_ASYNC_UNWIND_TABLES
+# define TARGET_DEFAULT_ASYNC_UNWIND_TABLES 1
+#endif
+#ifndef TARGET_DEFAULT_ISA_SPEC
+# define TARGET_DEFAULT_ISA_SPEC ISA_SPEC_CLASS_20191213
+#endif
+#ifndef TARGET_RISCV_ATTRIBUTE
+# define TARGET_RISCV_ATTRIBUTE 1
+#endif
+#ifndef TARGET_RISCV_DEFAULT_ARCH
+# define TARGET_RISCV_DEFAULT_ARCH rv32imafdc_zicsr_zifencei
+#endif
+#ifndef TARGET_RISCV_DEFAULT_ABI
+# define TARGET_RISCV_DEFAULT_ABI ilp32d
+#endif
 #ifdef IN_GCC
 # include "options.h"
 # include "insn-constants.h"
@@ -35,8 +50,5 @@
 #if defined IN_GCC && !defined GENERATOR_FILE
 # include "insn-modes.h"
 #endif
-#if defined IN_GCC && defined GENERATOR_FILE && !defined BITS_PER_UNIT
-#include "machmode.h"
-#endif
 # include "defaults.h"
 #endif /* GCC_TM_H */
